#This code is based on the code available at https://github.com/do9xe/aruba_api_caller
import json, requests, time, sys
import urllib3
urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)


class api_session:
    def __init__(self, api_url, username, password, port=4343, SSL=True, check_ssl=True, verbose=True, retrys=3,
                 retry_wait=0.5):
        if SSL:
            protocol = "https"
        else:
            protocol = "http"

        self.session = None
        self.api_token = None
        self.api_url = "{}://{}:{}/v1/".format(protocol, api_url, port)
        self.username = username
        self.password = password
        self.check_ssl = check_ssl
        self.verbose = verbose
        self.retrys = retrys
        self.retry_wait = retry_wait

    def login(self):
        self.session = requests.Session()
        for i in range(1, self.retrys + 1):
            if self.verbose:
                print("Verbose: login, try {}".format(str(i)))
            #print("{}api/login?username={}&password={}".format(self.api_url, self.username, self.password))
            response = self.session.get(
                "{}api/login?username={}&password={}".format(self.api_url, self.username, self.password),
                verify=self.check_ssl)
            login_data = json.loads(response.text)
            if self.verbose:
                print("Verbose: {}".format(login_data["_global_result"]["status_str"]))
            if login_data["_global_result"]["status"] == "0":
                self.api_token = login_data["_global_result"]["UIDARUBA"]
                return
            if i == self.retrys:
                if self.verbose:
                    print("There was an Error with the login. Please check the credentials.", file=sys.stderr)
                    print("Controller-IP: {}, Username: {}".format(self.api_url, self.username), file=sys.stderr)
                raise PermissionError(
                    "There was an Error with the login. Please check the credentials of the User >{}< at host >{}<".format(self.username, self.api_url))
            time.sleep(self.retry_wait)

    def logout(self):
        #print(self.api_url + "api/logout")
        response = self.session.get(self.api_url + "api/logout")
        logout_data = json.loads(response.text)
        self.api_token = None
        if self.verbose:
            print("Verbose: {}".format(logout_data["_global_result"]["status_str"]))

    def cli_command(self, command):
        mod_command = command.replace(" ", "+")
        #print("{}configuration/showcommand?json=1&command={}&UIDARUBA={}".format(self.api_url, mod_command, self.api_token))
        response = self.session.get(
            "{}configuration/showcommand?json=1&command={}&UIDARUBA={}".format(self.api_url, mod_command, self.api_token))

      #print("Response is " + response.text)
        data = json.loads(response.text)
        if self.verbose:
            print("Verbose: {}".format(str(data)))
        return data

